==> hhvm_3.2.0+dfsg1.orig.tar.xz: hhvm-3.2.0+dfsg/hphp/test/slow/ext_ezc_test/realpath_basic3.php <==
<?php
/* Prototype: string ezc_realpath ( string $path );
   Description: Returns canonicalized absolute pathname
*/

echo "\n*** Testing basic functions of ezc_realpath() with files ***\n";

/* creating directories and files */
$file_path = dirname(__FILE__);
mkdir("$file_path/realpath_basic/home/test/", 0777, true);

$file_handle1 = fopen("$file_path/realpath_basic/home/test/realpath_basic.tmp", "w");
$file_handle2 = fopen("$file_path/realpath_basic/home/realpath_basic.tmp", "w");
$file_handle3 = fopen("$file_path/realpath_basic/realpath_basic.tmp", "w");
fclose($file_handle1);
fclose($file_handle2);
fclose($file_handle3);

echo "\n*** Testing ezc_realpath() on filenames ***\n";
$filenames = array (
  /* filenames resulting in valid paths */
  "./realpath_basic/home/realpath_basic.tmp",
  "./realpath_basic/realpath_basic.tmp",
  "./realpath_basic//home/test//../test/./realpath_basic.tmp",
  "./realpath_basic/home//../././realpath_basic.tmp",

  /* filenames with invalid path */
  // checking for binary safe
  "./realpath_basicx000/home/realpath_basic.tmp",

  ".///realpath_basic/home//..//././test//realpath_basic.tmp",
  "./realpath_basic/home/../home/../test/..realpath_basic.tmp"
);

chdir("$file_path/..");
chdir($file_path);

$counter = 1;
/* loop through $files to read the filepath of $file in the above array */
foreach($filenames as $file) {
  echo "\n-- Iteration $counter --\n";
  var_dump( ezc_realpath($file) );
  $counter++;
}

echo "Done\n";
?>
<?php
$name_prefix = dirname(__FILE__)."/realpath_basic";
unlink("$name_prefix/home/test/realpath_basic.tmp");
unlink("$name_prefix/home/realpath_basic.tmp");
unlink("$name_prefix/realpath_basic.tmp");
rmdir("$name_prefix/home/test/");
rmdir("$name_prefix/home/");
rmdir("$name_prefix/");
?>

==> hhvm_3.21.0+dfsg.orig.tar.xz: hhvm-3.21.0+dfsg/hphp/test/slow/ext_ezc_test/realpath_basic3.php <==
<?php
/* Prototype: string ezc_realpath ( string $path );
   Description: Returns canonicalized absolute pathname
*/

echo "\n*** Testing basic functions of ezc_realpath() with files ***\n";

/* creating directories and files */
$file_path = dirname(__FILE__);
$dir_path = "$file_path/realpath_basic/home/test/";
system("rm -rf ".escapeshellarg($dir_path));
mkdir($dir_path, 0777, true);

$file_handle1 = fopen("$file_path/realpath_basic/home/test/realpath_basic.tmp", "w");
$file_handle2 = fopen("$file_path/realpath_basic/home/realpath_basic.tmp", "w");
$file_handle3 = fopen("$file_path/realpath_basic/realpath_basic.tmp", "w");
fclose($file_handle1);
fclose($file_handle2);
fclose($file_handle3);

echo "\n*** Testing ezc_realpath() on filenames ***\n";
$filenames = array (
  /* filenames resulting in valid paths */
  "./realpath_basic/home/realpath_basic.tmp",
  "./realpath_basic/realpath_basic.tmp",
  "./realpath_basic//home/test//../test/./realpath_basic.tmp",
  "./realpath_basic/home//../././realpath_basic.tmp",

  /* filenames with invalid path */
  // checking for binary safe
  "./realpath_basicx000/home/realpath_basic.tmp",

  ".///realpath_basic/home//..//././test//realpath_basic.tmp",
  "./realpath_basic/home/../home/../test/..realpath_basic.tmp"
);

chdir("$file_path/..");
chdir($file_path);

$counter = 1;
/* loop through $files to read the filepath of $file in the above array */
foreach($filenames as $file) {
  echo "\n-- Iteration $counter --\n";
  var_dump( ezc_realpath($file) );
  $counter++;
}

echo "Done\n";
?>
<?php
$name_prefix = dirname(__FILE__)."/realpath_basic";
unlink("$name_prefix/home/test/realpath_basic.tmp");
unlink("$name_prefix/home/realpath_basic.tmp");
unlink("$name_prefix/realpath_basic.tmp");
rmdir("$name_prefix/home/test/");
rmdir("$name_prefix/home/");
rmdir("$name_prefix/");
?>
